@echo off
:: =============================================================================
::  File:   INSTLANG.BAT
::  Author: TCD
::  Date:   7/24/2000
:: =============================================================================
::                                                                             
::                            Speedline Technologies                           
::                                16 Forge Park                                
::                              Franklin, MA 02038                             
::                                (508) 520-6999                               
::                                                                             
::                          Copyright (c) 1988 - 2000.                         
::                                                                             
:: =============================================================================
::  Batch File Description:
::    INSTLANG.BAT and LANGUAGE.BAT which do the installation of language
::    support files are based on some AP batch files.  INSTLANG.BAT which is
::    called by INSTALL.BAT does the following:
::
::      1. Create a subdirectory off of 'C:\SPMV' for each language
::
::           C:\SPMV\English
::           C:\SPMV\French
::           C:\SPMV\German
::           C:\SPMV\Spanish
::
::      2. Install the language support files by executing the following
::         self-extracting archive language '.EXE' files:
::
::           A:\SPMV\English\English.exe
::           A:\SPMV\French\French.exe
::           A:\SPMV\German\German.exe
::           A:\SPMV\Spanish\Spanish.exe
::
::           The language '.RSC' file and '*.HLP' files are extracted into the
::           language subdirectories off of 'C:\SPMV'.
::
::      3. English is installed as the default language by the following:
::
::           Copy C:\SPMV\English\English.rsc C:\SPMV\Strings.rsc
::
::           Copy C:\SPMV\English\*.hlp C:\SPMV\Help
::
::      4. Call LANGUAGE.BAT which provides the ability to install the selected
::         language by the following:
::
::           Copy the language '.RSC' file to 'C:\SPMV\STRINGS.RSC'
::
::           Copy the language '*.HLP' files into 'C:\SPMV\HELP'
::
::      LANGUAGE.BAT is called by INSTLANG.BAT or can be invoked directly by
::      entering C:\SPMV\LANGUAGE.BAT on the command line.
::
::   
::  History:
::      7/24/2000   Initial Release   
::
:: 
:: =============================================================================

:: ------------------- Setup the environment variable - idir ------------
set idir=SPMV

:: ------------------- Remove old string files if present ---------------
if exist c:\%idir%\English\english.rsc del c:\%idir%\English\*.* < A:\SPMV\Y.TXT > NUL
if exist c:\%idir%\French\french.rsc del c:\%idir%\French\*.* < A:\SPMV\Y.TXT > NUL
if exist c:\%idir%\German\german.rsc del c:\%idir%\German\*.* < A:\SPMV\Y.TXT > NUL
if exist c:\%idir%\Spanish\spanish.rsc del c:\%idir%\Spanish\*.* < A:\SPMV\Y.TXT > NUL

:: ------------------- Create directories if needed ---------------------
if not exist c:\%idir%\English\nul  md c:\%idir%\English
if not exist c:\%idir%\French\nul   md c:\%idir%\French
if not exist c:\%idir%\German\nul   md c:\%idir%\German
if not exist c:\%idir%\Spanish\nul  md c:\%idir%\Spanish


:: ------------------- Extract Language Files ---------------------------
if not exist a:\%idir%\English.exe  goto lang_extract_err
:: Execute the self-extracting archive 'English.exe'
c:
cd c:\%idir%\English
echo.
a:\%idir%\English

if not exist a:\%idir%\French.exe   goto lang_extract_err
:: Execute the self-extracting archive 'French.exe'
cd c:\%idir%\French
echo.
a:\%idir%\French

if not exist a:\%idir%\German.exe   goto lang_extract_err
:: Execute the self-extracting archive 'German.exe'
cd c:\%idir%\German
echo.
a:\%idir%\German

if not exist a:\%idir%\Spanish.exe  goto lang_extract_err
:: Execute the self-extracting archive 'Spanish.exe'
cd c:\%idir%\Spanish
echo.
a:\%idir%\Spanish


:: ------------------- Install the Default Language - English -----------
if not exist c:\%idir%\English\NUL         goto lang_dir_err
if not exist c:\%idir%\English\English.RSC goto lang_file_err
if not exist c:\%idir%\English\*.HLP       goto hlp_file_err

echo.
echo Default Language installed  --  English
echo.

cd c:\%idir%
copy c:\%idir%\English\English.rsc  c:\%idir%\Strings.rsc /y /v > null
copy c:\%idir%\English\*.hlp        c:\%idir%\Help\*.hlp  /y /v > null


:: ------------------- Install the User Selected Language ---------------
if not exist c:\%idir%\Language.bat goto lang_bat_err
call c:\%idir%\Language.bat
goto end

:lang_extract_err
cls
echo.
echo.
echo.
echo.
echo                    You can not extract the Language files!
echo.
echo             Self-Extracting Language file missing in SPMV directory
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto end

:lang_dir_err
cls
echo.
echo.
echo.
echo.
echo                     You can not install Language!
echo.
echo                     Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto end

:lang_file_err
cls
echo.
echo.
echo.
echo.
echo                     You can not install Default Language!
echo.
echo             Resource file in Default Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto end

:hlp_file_err
cls
echo.
echo.
echo.
echo.
echo                     You can not install Default Language!
echo.
echo             Help files in Default Language subdirectory missing
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto end

:lang_bat_err
cls
echo.
echo.
echo.
echo.
echo                 Can not install the User Selected Language!
echo.
echo                 Language Batch file missing in SPMV directory
echo.
echo             Contact Speedline Technologies Service Representative
echo.
echo.
pause
echo.
cls
goto end

:end
:: ------------------- Delete the environment variable - idir -----------
set idir=
